@@ -276,10 +276,13 @@ binary_ops = {
     "similar_to": "similar_to",
     "like": "like",
     "rlike": "rlike",
+    "ilike": "ilike",
     "not like": "not_like",
     "not_like": "not_like",
     "not rlike": "not_rlike",
     "not_rlike": "not_rlike",
+    "not ilike": "not_ilike",
+    "not_ilike": "not_ilike",
     "not_simlilar_to": "not_similar_to",
     "or": "or",
     "and": "and",
